# Revision &middot; [![CircleCI](https://circleci.com/gh/COLORFULBOARD/revision.svg?style=svg&circle-token=432185e19767b72ceacd6d59b26d295492afa410)](https://circleci.com/gh/COLORFULBOARD/revision)

## Getting Started

### Installation

To install the package, simply run:

```sh
$ pip install revision
```

Or install from source:

```sh
$ make install
```

### Running Lint

```sh
$ make lint
```

### Running Tests

```sh
$ make test
```

## Usage

Revision expects a configuration file to be present in the project root.

```sh
$ revision init
```

## License

Revision is licensed under MIT License. See [LICENSE](https://github.com/COLORFULBOARD/revision/blob/master/LICENSE) for more information.
